/*
   Combined DHT basic example (File > Examples > DHT sensor library > DHT unified sensor)
   and OLED display
   with Dabble Terminal example from https://thestempedia.com/docs/dabble/terminal-module/
   for BLE-Nano (https://home.et.utwente.nl/slootenvanf/2020/04/10/arduino-nano-ble/)

   Important: because the BLE-Nano has its Bluetooth module connected to the Serial port of the Arduino (RX/TX), you cannot use Serial.xxxxx together with the Dabble Terminal class!
   So all references to Serial.xxxxx have been removed from the DHT example
*/
// DHT Temperature & Humidity Sensor
// Unified Sensor Library Example
// Written by Tony DiCola for Adafruit Industries
// Released under an MIT license.

// REQUIRES the following Arduino libraries:
// - DHT Sensor Library: https://github.com/adafruit/DHT-sensor-library
// - Adafruit Unified Sensor Lib: https://github.com/adafruit/Adafruit_Sensor
// - Dabble: https://thestempedia.com/docs/dabble/getting-started-with-dabble/

#include <Adafruit_Sensor.h>
#include <DHT.h>
#include <DHT_U.h>
#include <U8g2lib.h>

// dabble:
#define CUSTOM_SETTINGS
#define INCLUDE_TERMINAL_MODULE
#include <Dabble.h>

bool connected = false;

#define DHTPIN 2     // Digital pin connected to the DHT sensor 
// Feather HUZZAH ESP8266 note: use pins 3, 4, 5, 12, 13 or 14 --
// Pin 15 can work but DHT must be disconnected during program upload.

// Uncomment the type of sensor in use:
#define DHTTYPE    DHT11     // DHT 11
//#define DHTTYPE    DHT22     // DHT 22 (AM2302)
//#define DHTTYPE    DHT21     // DHT 21 (AM2301)

// See guide for details on sensor wiring and usage:
//   https://learn.adafruit.com/dht/overview

DHT_Unified dht(DHTPIN, DHTTYPE);

uint32_t delayMS;

// display setup:
// software i2c:
//U8X8_SSD1306_128X64_NONAME_SW_I2C u8x8(7, 8, U8X8_PIN_NONE);
// hardware i2c:
U8X8_SSD1306_128X64_NONAME_HW_I2C display(U8X8_PIN_NONE);

char buf[10]; // text buffer for display; to be able to use draw2x2String to show the value
String Serialdata = ""; // text buffer for Dabble Terminal
String input = "";

void setup() {
  // Have Dabble connect to Bluetooth Module:
  Dabble.begin(9600, 0, 1); // Baudrate, RX, TX to which bluetooth module is connected, 0,1 = default RX,TX of Uno, Nano

  // Initialize device.
  dht.begin();
  sensor_t sensor;
  dht.temperature().getSensor(&sensor);
  // Set delay between sensor readings based on sensor details.
  delayMS = sensor.min_delay / 1000;

  // initialize display:
  display.begin();
  display.setPowerSave(0);
  display.setFont(u8x8_font_pxplusibmcgathin_f);

  display.clearDisplay();
  display.drawString(0, 0, "DHT sensor");
  display.draw2x2String(0, 2, "Temp:");
  display.drawString(0, 7, "Humidity:");
}

void loop() {
  // Delay between measurements.
  delay(delayMS);

  Dabble.processInput();

  // Get temperature event and print its value.
  sensors_event_t event;
  dht.temperature().getEvent(&event);
  if (isnan(event.temperature)) {
    Terminal.println(F("Error reading temperature!"));
  }
  else {
    Serialdata = "Temperature: ";
    Serialdata = String(Serialdata + event.temperature);
    Serialdata = String(Serialdata + "°C");
    Terminal.println(Serialdata);

    // display temperature on display:
    dtostrf(event.temperature, 3, 1, buf); // print float like XXX.X
    display.draw2x2String(0, 5, buf);
  }

  // Get humidity event and print its value.
  dht.humidity().getEvent(&event);
  if (isnan(event.relative_humidity)) {
    Terminal.println(F("Error reading humidity!"));
  }
  else {
    Serialdata = "Humidity: ";
    Serialdata = String(Serialdata + event.relative_humidity);
    Serialdata = String(Serialdata + "%");
    Terminal.println(Serialdata);

    // display humidity on display:
    dtostrf(event.relative_humidity, 3, 1, buf); // print float like XXX.X
    display.drawString(10, 7, buf);
  }
}
